@@ -41,8 +41,7 @@ object Automation {
         return rank
     }
 
-    val zeroFoodFocuses = setOf(CityFocus.CultureFocus, CityFocus.FaithFocus, CityFocus.GoldFocus,
-        CityFocus.HappinessFocus, CityFocus.ProductionFocus, CityFocus.ScienceFocus)
+
     private fun rankStatsForCityWork(stats: Stats, city: City, cityStats: Stats, specialist: Boolean, localUniqueCache: LocalUniqueCache): Float {
         val cityAIFocus = city.getCityFocus()
         val yieldStats = stats.clone()
@@ -65,7 +64,7 @@ object Automation {
 
         if (surplusFood > 0 && city.avoidGrowth) {
             yieldStats.food = 0f // don't need more food!
-        } else if (cityAIFocus in zeroFoodFocuses) {
+        } else if (cityAIFocus in CityFocus.zeroFoodFocuses()) {
             // Focus on non-food/growth
             if (surplusFood < 0)
                 yieldStats.food *= 8 // Starving, need Food, get to 0
@@ -77,8 +76,6 @@ object Automation {
                 yieldStats.food *= 8
             else if (city.population.population < 5)
                 yieldStats.food *= 3
-            else if (cityAIFocus == CityFocus.FoodFocus)
-                yieldStats.food *= 2
         }
 
         if (city.population.population < 5) {
