@@ -118,7 +118,7 @@ object NextTurnAutomation {
         civInfo.popupAlerts.clear() // AIs don't care about popups.
     }
 
-    internal fun valueCityStateAlliance(civInfo: Civilization, cityState: Civilization): Int {
+    internal fun valueCityStateAlliance(civInfo: Civilization, cityState: Civilization, includeQuests: Boolean = false): Int {
         var value = 0
 
         if (civInfo.wantsToFocusOn(Victory.Focus.Culture) && cityState.cityStateFunctions.canProvideStat(Stat.Culture)) {
@@ -150,8 +150,12 @@ object NextTurnAutomation {
 
         if (!cityState.isAlive() || cityState.cities.isEmpty() || civInfo.cities.isEmpty())
             return value
+        
+        // The more we have invested into the city-state the more the alliance is worth
+        val ourInfluence = cityState.getDiplomacyManager(civInfo).getInfluence().toInt()
+        value += ourInfluence / 10
 
-        if (civInfo.gold < 100) {
+        if (civInfo.gold < 100 && ourInfluence < 30) {
             // Consider bullying for cash
             value -= 5
         }
@@ -159,7 +163,7 @@ object NextTurnAutomation {
         if (cityState.getAllyCiv() != null && cityState.getAllyCiv() != civInfo.civName) {
             // easier not to compete if a third civ has this locked down
             val thirdCivInfluence = cityState.getDiplomacyManager(cityState.getAllyCiv()!!).getInfluence().toInt()
-            value -= (thirdCivInfluence - 60) / 10
+            value -= (thirdCivInfluence - 30) / 10
         }
 
         // Bonus for luxury resources we can get from them
@@ -167,6 +171,11 @@ object NextTurnAutomation {
             it.resource.resourceType == ResourceType.Luxury
             && it.resource !in civInfo.detailedCivResources.map { supply -> supply.resource }
         }
+        
+        if (includeQuests) {
+            // Investing is better if there is an investment bonus quest active.
+            value += (cityState.questManager.getInvestmentMultiplier(civInfo.civName) * 10).toInt() - 10
+        }
 
         return value
     }
