@@ -6,6 +6,7 @@ import com.badlogic.gdx.files.FileHandle
 import com.badlogic.gdx.utils.GdxRuntimeException
 import com.badlogic.gdx.utils.JsonReader
 import com.badlogic.gdx.utils.SerializationException
+import com.unciv.Constants
 import com.unciv.UncivGame
 import com.unciv.json.fromJsonFile
 import com.unciv.json.json
@@ -15,9 +16,12 @@ import com.unciv.logic.GameInfoPreview
 import com.unciv.logic.GameInfoSerializationVersion
 import com.unciv.logic.HasGameInfoSerializationVersion
 import com.unciv.logic.UncivShowableException
+import com.unciv.logic.civilization.PlayerType
+import com.unciv.logic.civilization.managers.TurnManager
 import com.unciv.models.metadata.GameSettings
 import com.unciv.models.metadata.doMigrations
 import com.unciv.models.metadata.isMigrationNecessary
+import com.unciv.models.ruleset.RulesetCache
 import com.unciv.ui.screens.savescreens.Gzip
 import com.unciv.utils.Concurrency
 import com.unciv.utils.Log
@@ -309,6 +313,33 @@ class UncivFiles(
         getGeneralSettingsFile().writeString(json().toJson(gameSettings), false, Charsets.UTF_8.name())
     }
 
+    val scenarioFolder = "scenarios"
+    fun getScenarioFiles() = sequence {
+
+        for (mod in RulesetCache.values) {
+            val modFolder = mod.folderLocation ?: continue
+            val scenarioFolder = modFolder.child(scenarioFolder)
+            if (scenarioFolder.exists())
+                for (file in scenarioFolder.list())
+                    yield(Pair(file, mod))
+        }
+    }
+
+    fun loadScenario(gameFile: FileHandle): GameInfo {
+        val game = loadGameFromFile(gameFile)
+        game.civilizations.removeAll { it.isSpectator() }
+        for (civ in game.civilizations)
+            civ.diplomacy.remove(Constants.spectator)
+        if (game.civilizations.none { it.isHuman() })
+            game.civilizations.first { it.isMajorCiv() }.playerType = PlayerType.Human
+
+        game.currentPlayerCiv = game.civilizations.first { it.playerType == PlayerType.Human }
+        game.currentPlayer = game.currentPlayerCiv.civName
+        TurnManager(game.currentPlayerCiv).startTurn()
+
+        return game
+    }
+
     companion object {
 
         var saveZipped = false
