@@ -23,7 +23,7 @@ object Log {
      */
     val disableLogsFrom = (
             System.getProperty("noLog")
-            ?: "Battle,Music,Sounds,Translations,WorkerAutomation"
+            ?: "Battle,Music,Sounds,Translations,WorkerAutomation,assignRegions"
         ).split(',').filterNot { it.isEmpty() }.toMutableSet()
 
     /**
@@ -143,6 +143,13 @@ object Log {
     fun error(tag: Tag, msg: String, throwable: Throwable) {
         doLog(backend::error, tag, buildThrowableMessage(msg, throwable))
     }
+
+    /**
+     * Get string information about operation system
+     */
+    fun getSystemInfo(): String {
+        return backend.getSystemInfo()
+    }
 }
 
 class Tag(val name: String)
@@ -153,6 +160,9 @@ interface LogBackend {
 
     /** Do not log on release builds for performance reasons. */
     fun isRelease(): Boolean
+
+    /** Get string information about operation system */
+    fun getSystemInfo(): String
 }
 
 /** Only for tests, or temporary main() functions */
@@ -168,6 +178,10 @@ open class DefaultLogBackend : LogBackend {
     override fun isRelease(): Boolean {
         return false
     }
+
+    override fun getSystemInfo(): String {
+        return ""
+    }
 }
 
 /** Shortcut for [Log.debug] */
@@ -218,6 +232,7 @@ private fun replaceLambdasWithValues(params: Array<out Any?>): Array<out Any?> {
 
 
 private fun getTag(): Tag {
+    @Suppress("ThrowingExceptionsWithoutMessageOrCause")
     val firstOutsideStacktrace = Throwable().stackTrace.filter { "com.unciv.utils.Log" !in it.className }.first()
     val simpleClassName = firstOutsideStacktrace.className.substringAfterLast('.')
     return Tag(removeAnonymousSuffix(simpleClassName))
